import random
from base64 import b64encode

def getSalt(max=10, rplc="-"):
    loop = random.randint(1, max)
    words = list("abcdefghijklmnopqrstuvwxyz1234567890")
    word = ""
    for _ in range(loop):
        get = random.choice(words)
        word += "".join([get.upper() if random.randint(0,1) == 1 else get.lower()])
    encrypted = reverseString(b64(word.encode()).decode()).replace("=", rplc)
    return encrypted

def getType(type):
    return "".join([reverseString(type).lower() if random.randint(0,1) == 0 else reverseString(type).upper()])

def b64(s):
    return b64encode(s)

def reverseString(string=""):
    return "".join(reversed(string))


import sys
import random
from .utils import getSalt, reverseString, b64, getType
from .exceptions import *

class Garuda45:
    def __init__(self):
        super().__init__()

        self.salt = getSalt(3)
        self.type = getType("Garuda45")
        self.output = ""

    @property
    def show(self):
        print (self.output)

    @property
    def result(self):
        return self.output

    def encrypt(self, s=""):
        if s == "":
            raise G30SValueError("Unknown error, please read a document")
        reverse = reverseString(s)
        encToB64 = b64(reverse.encode()).decode()
        results = self.salt + encToB64 + self.type + str(len(self.salt))
        self.output = results

class Garuda1945:
    def __init__(self):
        super().__init__()

        self.string = ""
        self.output = ""
        self.type = getType("Garuda1945")
        self.salt = getSalt(10, "=")
        self.rand = random.randint(1, len(self.string) + 10)

    @property
    def show(self):
        print (self.output)
    
    @property
    def result(self):
        return self.output

    def encrypt(self, s=""):
        self.string = s
        if s == "":
            raise G30SValueError("Unknown error, please read a document")
        num = [x for x in range(self.rand)]
        enc = b64(s.encode()).decode()
        word = ""
        for x in enc:
            word += b64(x.encode()).decode()[0]
        results = self.salt + word + self.type + str(len(self.salt))
        self.output = results



from distutils.core import setup
setup(
  name = 'G30S',
  packages = ['G30S'],
  version = '0.1',
  license='MIT',
  description = 'Simple text encoder using python',
  author = 'Billal X Code',
  author_email = 'billal.xcode@gmail.com',
  url = 'https://github.com/billalxcode/G30S',
  keywords = ['encoder', 'encrypt', 'crypto', 'decoder', 'encoding', 'hash', 'g30s', 'indonesian', 'python', 'base64'],
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
